==> haskell-tamarin-prover-sapic-1.10.0-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.10.0
visibility:           public
id:                   tamarin-prover-sapic-1.10.0-IQqrXnyvdwhBcXz5iLPMZ6
key:                  tamarin-prover-sapic-1.10.0-IQqrXnyvdwhBcXz5iLPMZ6
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  e0391f027b1ade20bf4a1cb6156a058e
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.10.0-IQqrXnyvdwhBcXz5iLPMZ6
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    aeson-pretty-0.8.10-LBJ177aL2uN3HrqwVlBpw9 base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    fclabels-2.0.5.1-3YelYxEPdt85B7Mq0wU3QH mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD parsec-3.1.16.1
    process-1.6.19.0 raw-strings-qq-1.1-HgsCJbBD5QVLggpDhmUWHl
    safe-0.3.21-EsRFO8M87PCEtDqVSuBNfo
    tamarin-prover-term-1.10.0-JBUuLi6ad1wGizuxOf3geX
    tamarin-prover-theory-1.10.0-GAqlp4VxdRt233WnhAJzfT
    tamarin-prover-utils-1.10.0-KegB8iQu0YkGYjq48w99kc text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-8Pbvi4nCeGU4g9X001jnYk

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-sapic-1.10.0-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.10.0
visibility:           public
id:                   tamarin-prover-sapic-1.10.0-7cx77V04Rrj975AimXPunb
key:                  tamarin-prover-sapic-1.10.0-7cx77V04Rrj975AimXPunb
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  3094635efc78c9a7f89ad1def1df0891
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.10.0-7cx77V04Rrj975AimXPunb
depends:
    aeson-2.1.2.1-6DouAcLayfd1cKsM4PdlxR
    aeson-pretty-0.8.10-AABvmKOgjm1WKNxOhOXTU base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    dlist-1.0-6YzbXMcxKqeIvtwDeZuPsh exceptions-0.10.7
    fclabels-2.0.5.1-Jr6AkXrxW0J9U8Yz0sA4D2 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD parsec-3.1.16.1
    process-1.6.19.0 raw-strings-qq-1.1-HgsCJbBD5QVLggpDhmUWHl
    safe-0.3.21-Jx1j9PonLpAIXmir4WvZhd
    tamarin-prover-term-1.10.0-IDH8YBZtyMFH96eoyLF8GU
    tamarin-prover-theory-1.10.0-E5E6dMewxWa55noKAHDqFk
    tamarin-prover-utils-1.10.0-B2aI01YBAjv5jqpHPd5Rd7 text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-A8zwL5hEDFDZxij87DDBG

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
